You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2013/11/21 23:30:32 UTC

svn commit: r1544347 - in /commons/proper/codec/trunk/src: main/java/org/apache/commons/codec/binary/ main/java/org/apache/commons/codec/language/ site/xdoc/ test/java/org/apache/commons/codec/binary/

Author: ggregory
Date: Thu Nov 21 22:30:31 2013
New Revision: 1544347

URL: http://svn.apache.org/r1544347
Log: (empty)

Modified:
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/binary/BaseNCodecOutputStream.java
    commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/DoubleMetaphone.java
    commons/proper/codec/trunk/src/site/xdoc/mail-lists.xml
    commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base32InputStreamTest.java
    commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base32OutputStreamTest.java
    commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base64InputStreamTest.java

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/binary/BaseNCodecOutputStream.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/binary/BaseNCodecOutputStream.java?rev=1544347&r1=1544346&r2=1544347&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/DoubleMetaphone.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/DoubleMetaphone.java Thu Nov 21 22:30:31 2013
@@ -622,7 +622,7 @@ public class DoubleMetaphone implements 
                    contains(value, index + 1, 1, "Z")) {
             //-- german & anglicisations, e.g. "smith" match "schmidt" //
             // "snider" match "schneider" --//
-            //-- also, -sz- in slavic language altho in hungarian it //
+            //-- also, -sz- in slavic language although in hungarian it //
             //   is pronounced "s" --//
             result.append('S', 'X');
             index = contains(value, index + 1, 1, "Z") ? index + 2 : index + 1;
@@ -850,7 +850,7 @@ public class DoubleMetaphone implements 
     //-- BEGIN HELPER FUNCTIONS --//
 
     /**
-     * Determines whether or not a value is of slavo-germanic orgin. A value is
+     * Determines whether or not a value is of slavo-germanic origin. A value is
      * of slavo-germanic origin if it contians any of 'W', 'K', 'CZ', or 'WITZ'.
      */
     private boolean isSlavoGermanic(final String value) {

Modified: commons/proper/codec/trunk/src/site/xdoc/mail-lists.xml
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/site/xdoc/mail-lists.xml?rev=1544347&r1=1544346&r2=1544347&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/site/xdoc/mail-lists.xml (original)
+++ commons/proper/codec/trunk/src/site/xdoc/mail-lists.xml Thu Nov 21 22:30:31 2013
@@ -149,7 +149,7 @@ limitations under the License.
           <td>
             <strong>Commons Commits List</strong>
             <br /><br />
-            Only for e-mails automatically generated by the <a href="source-repository.html">source control</a> sytem.
+            Only for e-mails automatically generated by the <a href="source-repository.html">source control</a> system.
             <br /><br />
           </td>
           <td><a href="mailto:commits-subscribe@commons.apache.org">Subscribe</a></td>

Modified: commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base32InputStreamTest.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base32InputStreamTest.java?rev=1544347&r1=1544346&r2=1544347&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base32InputStreamTest.java (original)
+++ commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base32InputStreamTest.java Thu Nov 21 22:30:31 2013
@@ -278,17 +278,17 @@ public class Base32InputStreamTest {
      *            the data from above, but decoded
      * @param chunkSize
      *            chunk size (line-length) of the base32 encoded data.
-     * @param seperator
+     * @param separator
      *            Line separator in the base32 encoded data.
      * @throws Exception
      *             Usually signifies a bug in the Base32 commons-codec implementation.
      */
-    private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] seperator) throws Exception {
+    private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
 
         // Start with encode.
         InputStream in;
 
-        in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, seperator);
+        in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
         byte[] output = Base32TestData.streamToBytes(in);
 
         assertEquals("EOF", -1, in.read());
@@ -306,7 +306,7 @@ public class Base32InputStreamTest {
         // I always wanted to do this! (wrap encoder with decoder etc etc).
         in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
-            in = new Base32InputStream(in, true, chunkSize, seperator);
+            in = new Base32InputStream(in, true, chunkSize, separator);
             in = new Base32InputStream(in, false);
         }
         output = Base32TestData.streamToBytes(in);
@@ -330,16 +330,16 @@ public class Base32InputStreamTest {
      *            the data from above, but decoded
      * @param chunkSize
      *            chunk size (line-length) of the base32 encoded data.
-     * @param seperator
+     * @param separator
      *            Line separator in the base32 encoded data.
      * @throws Exception
      *             Usually signifies a bug in the Base32 commons-codec implementation.
      */
-    private void testByteByByte(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] seperator) throws Exception {
+    private void testByteByByte(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
 
         // Start with encode.
         InputStream in;
-        in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, seperator);
+        in = new Base32InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
         byte[] output = new byte[encoded.length];
         for (int i = 0; i < output.length; i++) {
             output[i] = (byte) in.read();
@@ -367,7 +367,7 @@ public class Base32InputStreamTest {
         // I always wanted to do this! (wrap encoder with decoder etc etc).
         in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
-            in = new Base32InputStream(in, true, chunkSize, seperator);
+            in = new Base32InputStream(in, true, chunkSize, separator);
             in = new Base32InputStream(in, false);
         }
         output = new byte[decoded.length];

Modified: commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base32OutputStreamTest.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base32OutputStreamTest.java?rev=1544347&r1=1544346&r2=1544347&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base32OutputStreamTest.java (original)
+++ commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base32OutputStreamTest.java Thu Nov 21 22:30:31 2013
@@ -170,16 +170,16 @@ public class Base32OutputStreamTest {
      *            the data from above, but decoded
      * @param chunkSize
      *            chunk size (line-length) of the Base32 encoded data.
-     * @param seperator
+     * @param separator
      *            Line separator in the Base32 encoded data.
      * @throws Exception
      *             Usually signifies a bug in the Base32 commons-codec implementation.
      */
-    private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] seperator) throws Exception {
+    private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
 
         // Start with encode.
         ByteArrayOutputStream byteOut = new ByteArrayOutputStream();
-        OutputStream out = new Base32OutputStream(byteOut, true, chunkSize, seperator);
+        OutputStream out = new Base32OutputStream(byteOut, true, chunkSize, separator);
         out.write(decoded);
         out.close();
         byte[] output = byteOut.toByteArray();
@@ -198,7 +198,7 @@ public class Base32OutputStreamTest {
         out = byteOut;
         for (int i = 0; i < 10; i++) {
             out = new Base32OutputStream(out, false);
-            out = new Base32OutputStream(out, true, chunkSize, seperator);
+            out = new Base32OutputStream(out, true, chunkSize, separator);
         }
         out.write(decoded);
         out.close();
@@ -220,16 +220,16 @@ public class Base32OutputStreamTest {
      *            the data from above, but decoded
      * @param chunkSize
      *            chunk size (line-length) of the Base32 encoded data.
-     * @param seperator
+     * @param separator
      *            Line separator in the Base32 encoded data.
      * @throws Exception
      *             Usually signifies a bug in the Base32 commons-codec implementation.
      */
-    private void testByteByByte(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] seperator) throws Exception {
+    private void testByteByByte(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
 
         // Start with encode.
         ByteArrayOutputStream byteOut = new ByteArrayOutputStream();
-        OutputStream out = new Base32OutputStream(byteOut, true, chunkSize, seperator);
+        OutputStream out = new Base32OutputStream(byteOut, true, chunkSize, separator);
         for (final byte element : decoded) {
             out.write(element);
         }
@@ -263,7 +263,7 @@ public class Base32OutputStreamTest {
         out = byteOut;
         for (int i = 0; i < 10; i++) {
             out = new Base32OutputStream(out, false);
-            out = new Base32OutputStream(out, true, chunkSize, seperator);
+            out = new Base32OutputStream(out, true, chunkSize, separator);
         }
         for (final byte element : decoded) {
             out.write(element);

Modified: commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base64InputStreamTest.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base64InputStreamTest.java?rev=1544347&r1=1544346&r2=1544347&view=diff
==============================================================================
--- commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base64InputStreamTest.java (original)
+++ commons/proper/codec/trunk/src/test/java/org/apache/commons/codec/binary/Base64InputStreamTest.java Thu Nov 21 22:30:31 2013
@@ -291,16 +291,16 @@ public class Base64InputStreamTest {
      *            the data from above, but decoded
      * @param chunkSize
      *            chunk size (line-length) of the base64 encoded data.
-     * @param seperator
+     * @param separator
      *            Line separator in the base64 encoded data.
      * @throws Exception
      *             Usually signifies a bug in the Base64 commons-codec implementation.
      */
-    private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] seperator) throws Exception {
+    private void testByChunk(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
 
         // Start with encode.
         InputStream in;
-        in = new Base64InputStream(new ByteArrayInputStream(decoded), true, chunkSize, seperator);
+        in = new Base64InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
         byte[] output = Base64TestData.streamToBytes(in);
 
         assertEquals("EOF", -1, in.read());
@@ -320,7 +320,7 @@ public class Base64InputStreamTest {
         // I always wanted to do this! (wrap encoder with decoder etc etc).
         in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
-            in = new Base64InputStream(in, true, chunkSize, seperator);
+            in = new Base64InputStream(in, true, chunkSize, separator);
             in = new Base64InputStream(in, false);
         }
         output = Base64TestData.streamToBytes(in);
@@ -344,16 +344,16 @@ public class Base64InputStreamTest {
      *            the data from above, but decoded
      * @param chunkSize
      *            chunk size (line-length) of the base64 encoded data.
-     * @param seperator
+     * @param separator
      *            Line separator in the base64 encoded data.
      * @throws Exception
      *             Usually signifies a bug in the Base64 commons-codec implementation.
      */
-    private void testByteByByte(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] seperator) throws Exception {
+    private void testByteByByte(final byte[] encoded, final byte[] decoded, final int chunkSize, final byte[] separator) throws Exception {
 
         // Start with encode.
         InputStream in;
-        in = new Base64InputStream(new ByteArrayInputStream(decoded), true, chunkSize, seperator);
+        in = new Base64InputStream(new ByteArrayInputStream(decoded), true, chunkSize, separator);
         byte[] output = new byte[encoded.length];
         for (int i = 0; i < output.length; i++) {
             output[i] = (byte) in.read();
@@ -380,7 +380,7 @@ public class Base64InputStreamTest {
         // I always wanted to do this! (wrap encoder with decoder etc etc).
         in = new ByteArrayInputStream(decoded);
         for (int i = 0; i < 10; i++) {
-            in = new Base64InputStream(in, true, chunkSize, seperator);
+            in = new Base64InputStream(in, true, chunkSize, separator);
             in = new Base64InputStream(in, false);
         }
         output = new byte[decoded.length];
--- commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/binary/BaseNCodecOutputStream.java (original)
+++ commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/binary/BaseNCodecOutputStream.java Thu Nov 21 22:30:31 2013
@@ -99,15 +99,15 @@ public class BaseNCodecOutputStream exte
     }
 
     /**
      * Flushes this output stream and forces any buffered output bytes to be written out to the stream. If propogate is
      * true, the wrapped stream will also be flushed.
      *
-     * @param propogate
+     * @param propagate
      *            boolean flag to indicate whether the wrapped OutputStream should also be flushed.
      * @throws IOException
      *             if an I/O error occurs.
      */
-    private void flush(final boolean propogate) throws IOException {
+    private void flush(final boolean propagate) throws IOException {
         final int avail = baseNCodec.available(context);
         if (avail > 0) {
             final byte[] buf = new byte[avail];
@@ -116,7 +116,7 @@ public class BaseNCodecOutputStream exte
                 out.write(buf, 0, c);
             }
         }
-        if (propogate) {
+        if (propagate) {
             out.flush();
         }
     }
@@ -99,15 +99,15 @@ public class BaseNCodecOutputStream exte
 
     /**
-     * Flushes this output stream and forces any buffered output bytes to be written out to the stream. If propogate is
+     * Flushes this output stream and forces any buffered output bytes to be written out to the stream. If propagate is
      * true, the wrapped stream will also be flushed.
      *

Modified: commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/DoubleMetaphone.java
URL: http://svn.apache.org/viewvc/commons/proper/codec/trunk/src/main/java/org/apache/commons/codec/language/DoubleMetaphone.java?rev=1544347&r1=1544346&r2=1544347&view=diff
==============================================================================